searchData={"items":[{"type":"module","title":"Hyperscan","doc":"","ref":"Hyperscan.html"},{"type":"function","title":"Hyperscan.alloc_scratch/1","doc":"Allocate a scratch memory buffer for running the regex.","ref":"Hyperscan.html#alloc_scratch/1"},{"type":"function","title":"Hyperscan.clone_scratch/1","doc":"Create a new scratch buffer of the same size.","ref":"Hyperscan.html#clone_scratch/1"},{"type":"function","title":"Hyperscan.compile/3","doc":"Compile a regular expression into a database.\n\n- `expression` is a regular expression, without the leading and trailing `/` characters or flags.\n- `flags` is an integer. Use 0 for no flags, or bitwise-or together one or more results of the flag/1 function.\n- `mode` is an integer similar to `flags`.\n\nReturns `{:ok, db}` where db represents the compiled regex, or `{:error, reason}` on error.\n\nSee the [docs] for more information:\n\n[docs]: http://intel.github.io/hyperscan/dev-reference/api_files.html#c.hs_compile\n\n# Example\n\n    iex> flags = Hyperscan.flag(\"HS_FLAG_CASELESS\")\n    iex> mode = Hyperscan.mode(\"HS_MODE_BLOCK\")\n    iex> {:ok, _db} = Hyperscan.compile(\"foo\", flags, mode)","ref":"Hyperscan.html#compile/3"},{"type":"function","title":"Hyperscan.compile_multi/4","doc":"Compile multiple regular expressions into a database.\n\n- `expression_list` is a list of regular expressions, without the leading\n  and trailing `/` characters or flags.\n- `flags_list` is a list of flags, one for each expression in\n  `expression_list`. To use multiple flags for a single expression,\n  bitwise-or them togther. Zero means no flags.\n- `id_list` is a list of arbitrary integers, with one value for each\n  expression in `expression_list`. An ID will be returned from\n  match_multi/3 if its corresponding expression matches the input string.\n- `mode` is an integer returned by mode/1.\n\nSee the [docs] for more information:\n\n[docs]: http://intel.github.io/hyperscan/dev-reference/api_files.html#c.hs_compile_multi\n\n# Example\n\n    iex> flags = Hyperscan.flag(\"HS_FLAG_CASELESS\")\n    iex> mode = Hyperscan.mode(\"HS_MODE_BLOCK\")\n    iex> {:ok, db} = Hyperscan.compile_multi([\"foo\", \"bar\"], [flags, flags], [1, 2], mode)\n    iex> {:ok, scratch} = Hyperscan.alloc_scratch(db)\n    iex> Hyperscan.match_multi(db, \"Foo\", scratch)\n    {:ok, [1]}\n    iex> Hyperscan.match_multi(db, \"Bar\", scratch)\n    {:ok, [2]}\n    iex> Hyperscan.match_multi(db, \"Baz\", scratch)\n    {:ok, []}","ref":"Hyperscan.html#compile_multi/4"},{"type":"function","title":"Hyperscan.expression_info/2","doc":"Returns a map with debugging info about a regular expression.","ref":"Hyperscan.html#expression_info/2"},{"type":"function","title":"Hyperscan.flag/1","doc":"Look up a flag constant by name.\n\nReturns the integer value of the Hyperscan flag constant with the given\nname. Names follow the pattern `HS_FLAG_*`. See the [docs] for available flag\nnames.\n\n[docs]: https://intel.github.io/hyperscan/dev-reference/api_files.html#c.HS_FLAG_CASELESS\n\nThe value is used by the compile and compile_multi functions. To use\nmultiple flags simultaneously, combine their values with Bitwise.bor/2.\n\nRaises :badarg if it is not a valid flag name.\n\n# Example\n\n    iex> Hyperscan.flag(\"HS_FLAG_CASELESS\")\n    1","ref":"Hyperscan.html#flag/1"},{"type":"function","title":"Hyperscan.match/3","doc":"Test whether the given compiled regex matches a string.\n\nRequires a scratch buffer allocated by alloc_scratch/1.","ref":"Hyperscan.html#match/3"},{"type":"function","title":"Hyperscan.match_multi/3","doc":"Test whether multiple compiled regexes match a string.\n\nThe regex should be compiled by compile_multi. Returns a list of expression\nIDs that matched the string. Note that the order of the returned IDs is\nundefined.\n\nSee the docs for compile_multi/4 for more info.","ref":"Hyperscan.html#match_multi/3"},{"type":"function","title":"Hyperscan.mode/1","doc":"Look up a mode constant by name.\n\nReturns the integer value of the Hyperscan mode constant with the given\nname. Names follow the pattern `HS_MODE_*`. See the [docs] for available mode\nnames.\n\n[docs]: https://intel.github.io/hyperscan/dev-reference/api_files.html#c.HS_MODE_BLOCK\n\nThe value is used by the compile and compile_multi functions. To use\nmultiple modes simultaneously, combine their values with Bitwise.bor/2.\n\nRaises :badarg if it is not a valid mode name.\n\n# Example\n\n    iex> Hyperscan.mode(\"HS_MODE_BLOCK\")\n    1","ref":"Hyperscan.html#mode/1"},{"type":"function","title":"Hyperscan.realloc_scratch/2","doc":"Re-allocate a scratch memory buffer.\n\nIf the scratch was allocated for a different database and is too small for\nthe given one, it will be reallocated. Either way, the scratch is now safe\nto use for the given database. Returns :ok.","ref":"Hyperscan.html#realloc_scratch/2"},{"type":"function","title":"Hyperscan.replace/4","doc":"Replace parts of a string that match a regular expression.\n\nThe database must have been compiled with HS_FLAG_SOM_LEFTMOST.\n\nRequires a scratch buffer allocated by alloc_scratch/1.\n\n# Example\n\n    iex> {:ok, db} = compile(\"b\", flag(\"HS_FLAG_SOM_LEFTMOST\"), mode(\"HS_MODE_BLOCK\"))\n    iex> {:ok, scratch} = alloc_scratch(db)\n    iex> Hyperscan.replace(db, \"a b c\", \"x\", scratch)\n    {:ok, \"a x c\"}","ref":"Hyperscan.html#replace/4"},{"type":"function","title":"Hyperscan.scratch_size/1","doc":"Check the size of a scratch buffer.","ref":"Hyperscan.html#scratch_size/1"},{"type":"function","title":"Hyperscan.valid_platform/0","doc":"Check if the current system architecture supports Hyperscan.","ref":"Hyperscan.html#valid_platform/0"},{"type":"function","title":"Hyperscan.version/0","doc":"Returns the compiled Hyperscan version as a string.","ref":"Hyperscan.html#version/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}